==> spring-cloud-cli-1.0.6.RELEASE-sources.jar: org/springframework/cloud/cli/compiler/EurekaServerCompilerAutoConfiguration.java <==
/*
 * Copyright 2013-2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.cloud.cli.compiler;

import org.codehaus.groovy.ast.ClassNode;
import org.codehaus.groovy.control.CompilationFailedException;
import org.codehaus.groovy.control.customizers.ImportCustomizer;
import org.springframework.boot.cli.compiler.AstUtils;
import org.springframework.boot.cli.compiler.CompilerAutoConfiguration;
import org.springframework.boot.cli.compiler.DependencyCustomizer;

/**
 * @author Dave Syer
 *
 */
public class EurekaServerCompilerAutoConfiguration extends CompilerAutoConfiguration {

	@Override
	public boolean matches(ClassNode classNode) {
		return AstUtils.hasAtLeastOneAnnotation(classNode, "EnableEurekaServer");
	}

	@Override
	public void applyDependencies(DependencyCustomizer dependencies) {
		dependencies.ifAnyMissingClasses(
				"org.springframework.cloud.netflix.eureka.server.EnableEurekaServer")
				.add("spring-cloud-starter-eureka-server");
	}

	@Override
	public void applyImports(ImportCustomizer imports) throws CompilationFailedException {
		imports.addImports("org.springframework.cloud.netflix.eureka.server.EnableEurekaServer",
				"org.springframework.cloud.client.discovery.EnableDiscoveryClient",
				"org.springframework.cloud.netflix.eureka.EurekaServerConfigBean",
				"org.springframework.cloud.netflix.eureka.EurekaInstanceConfigBean",
				"org.springframework.cloud.netflix.eureka.EurekaClientConfigBean",
				"com.netflix.discovery.DiscoveryClient",
				"com.netflix.appinfo.InstanceInfo");
	}

}

==> spring-cloud-cli-1.2.1.RELEASE-sources.jar: org/springframework/cloud/cli/compiler/EurekaServerCompilerAutoConfiguration.java <==
/*
 * Copyright 2013-2014 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.cloud.cli.compiler;

import org.codehaus.groovy.ast.ClassNode;
import org.codehaus.groovy.control.CompilationFailedException;
import org.codehaus.groovy.control.customizers.ImportCustomizer;
import org.springframework.boot.cli.compiler.AstUtils;
import org.springframework.boot.cli.compiler.CompilerAutoConfiguration;
import org.springframework.boot.cli.compiler.DependencyCustomizer;

/**
 * @author Dave Syer
 *
 */
public class EurekaServerCompilerAutoConfiguration extends CompilerAutoConfiguration {

	@Override
	public boolean matches(ClassNode classNode) {
		return AstUtils.hasAtLeastOneAnnotation(classNode, "EnableEurekaServer");
	}

	@Override
	public void applyDependencies(DependencyCustomizer dependencies) {
		dependencies.ifAnyMissingClasses(
				"org.springframework.cloud.netflix.eureka.server.EnableEurekaServer")
				.add("spring-cloud-starter-eureka-server");
	}

	@Override
	public void applyImports(ImportCustomizer imports) throws CompilationFailedException {
		imports.addImports("org.springframework.cloud.netflix.eureka.server.EnableEurekaServer",
				"org.springframework.cloud.client.discovery.EnableDiscoveryClient",
				"org.springframework.cloud.netflix.eureka.server.EurekaServerConfigBean",
				"org.springframework.cloud.netflix.eureka.EurekaInstanceConfigBean",
				"org.springframework.cloud.netflix.eureka.EurekaClientConfigBean",
				"com.netflix.discovery.DiscoveryClient",
				"com.netflix.appinfo.InstanceInfo");
	}

}
